[![@wq/react][logo]][docs]

**@wq/react** is a renderer plugin for [@wq/app] that seamlessly integrates with the [React] and [React Native] frameworks.  @wq/react provides a number of default [components] and [hooks] to facilitate rapid deployment of applications backed by @wq/app's storage, data model, routing, and syncing engines ([@wq/store], [@wq/model], [@wq/router], and [@wq/outbox], respectively.)

@wq/react is meant to be used with [@wq/material], which provides a collection of ready-to-use Material Design interface components.

### [Documentation][docs]

[**Installation**][installation]
&bull;
[**API**][api]
&bull;
[**Components**][components]
&bull;
[Icons][icons]
&bull;
[Inputs][inputs]
&bull;
[Views][views]
&bull;
[**Hooks**][hooks]

[logo]: https://wq.io/images/@wq/react.svg
[docs]: https://wq.io/@wq/react
[installation]: https://wq.io/@wq/react#installation
[api]: https://wq.io/@wq/react#api
[components]: https://wq.io/components/
[icons]: https://wq.io/icons/
[inputs]: https://wq.io/inputs/
[views]: https://wq.io/views/
[hooks]: https://wq.io/hooks/

[@wq/app]: https://wq.io/@wq/app
[@wq/store]: https://wq.io/@wq/store
[@wq/model]: https://wq.io/@wq/model
[@wq/router]: https://wq.io/@wq/router
[@wq/outbox]: https://wq.io/@wq/outbox
[@wq/material]: https://wq.io/@wq/material

[React]: https://reactjs.org
[React Native]: https://reactnative.dev/
